@@ -3,13 +3,13 @@ package org.gcube.portlets.user.td.gwtservice.shared.tr.groupby;
 import java.io.Serializable;
 import java.util.HashMap;
 
-import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnData;
 
 /**
  * 
- * @author "Giancarlo Panichi" <a
- *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
+ * @author Giancarlo Panichi
+ *
  * 
  */
 public class TimeAggregationSession implements Serializable {
@@ -24,12 +24,7 @@ public class TimeAggregationSession implements Serializable {
 
 	}
 
-	/**
-	 * 
-	 * @param trId
-	 * @param column
-	 * @param map
-	 */
+	
 	public TimeAggregationSession(TRId trId, ColumnData column,
 			HashMap<String, Object> map) {
 		super();
